==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/id-ID/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Pengguna ini dapat masuk',
    'activated_disabled_help_text' => 'Anda tidak dapat menyunting status aktivasi akun anda sendiri.',
    'assets_user'       => 'Aset pada :name',
    'bulk_update_warn'	=> 'Anda akan mengedit properti dari: user_count pengguna. Harap perhatikan bahwa Anda tidak dapat mengubah atribut pengguna Anda sendiri menggunakan formulir ini, dan harus melakukan pengeditan kepada pengguna Anda sendiri satu per satu.',
    'bulk_update_help'	=> 'Formulir ini memungkinkan Anda untuk memperbarui beberapa pengguna sekaligus. Isi saja bidang yang perlu Anda ubah. Setiap bidang yang dikosongkan akan tetap tidak berubah.',
    'current_assets'    => 'Aset ini untuk pengguna ini',
    'clone'             => 'Klon pengguna',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'Sunting Pengguna',
    'filetype_info'     => 'Jenis berkas diizinkan adalah png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, dan rar.',
    'history_user'      => 'Riwayat untuk :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klik di sini untuk mengembalikannya.',
    'last_login'        => 'Terakhir masuk',
    'ldap_config_text'  => 'Konfigurasi LDAP terdapat di Admin > Pengaturan. Jika lokasi di pilih, maka akan di impor untuk semua pengguna.',
    'print_assigned'    => 'Cetak Semua Ditugaskan',
    'email_assigned'    => 'Daftar Email Semua yang Ditetapkan',
    'user_notified'     => 'Pengguna telah dikirimi email berisi daftar item yang saat ini ditetapkan kepada mereka.',
    'auto_assign_label' => 'Sertakan pengguna ini saat penugasan otomatis lisensi yang memenuhi syarat',
    'auto_assign_help'  => 'Lewati pengguna ini dalam penetapan otomatis lisensi',
    'software_user'     => 'Perangkat lunak pada :name',
    'send_email_help'   => 'Anda harus memberikan alamat email pengguna ini untuk mengirimkan kredensial kepada mereka. Pengiriman email kredensial hanya dapat dilakukan pada pembuatan user. Kata sandi disimpan dalam hash satu arah dan tidak dapat diambil setelah disimpan.',
    'view_user'         => 'Lihat pengguna: name',
    'usercsv'           => 'Berkas CSV',
    'two_factor_admin_optin_help' => 'Pengaturan admin Anda saat ini memungkinkan penegakan dua faktor otentikasi selektif.',
    'two_factor_enrolled' => 'Perangkat 2FA Terdaftar',
    'two_factor_active'   => '2FA Aktif',
    'user_deactivated'  => 'Pengguna tidak dapat masuk',
    'user_activated'  => 'Pengguna dapat masuk',
    'activation_status_warning' => 'Jangan ubah status aktivasi',
    'group_memberships_helpblock' => 'Hanya superadmin yang dapat mengedit keanggotaan grup.',
    'superadmin_permission_warning' => 'Hanya superadmin yang dapat memberikan akses superadmin kepada pengguna.',
    'admin_permission_warning' => 'Hanya pengguna dengan hak admin atau lebih tinggi yang dapat memberikan akses admin kepada pengguna.',
    'remove_group_memberships' => 'Hapus Keanggotaan Grup',
    'warning_deletion_information' => 'Anda akan mengembalikan SEMUA item dari :count pengguna (-pengguna) yang terdaftar di bawah ini. Nama superadmin disorot dengan warna merah.',
    'update_user_assets_status' => 'Perbarui semua aset untuk pengguna ini ke status ini',
    'checkin_user_properties' => 'Kembalikan semua properti yang terkait dengan pengguna ini',
    'remote_label'   => 'Ini adalah pengguna jarak jauh',
    'remote'   => 'Jarak Jauh',
    'remote_help' => 'Ini dapat berguna jika Anda perlu memfilter berdasarkan pengguna jarak jauh yang tidak pernah atau jarang datang ke lokasi fisik Anda.',
    'not_remote_label' => 'Ini bukan pengguna jarak jauh',
    'vip_label' => 'Pengguna VIP',
    'vip_help' => 'Ini dapat bermanfaat untuk menandai orang-orang penting di organisasi Anda jika Anda ingin menangani mereka dengan cara khusus.',
    'create_user' => 'Buat pengguna',
    'create_user_page_explanation' => 'Ini adalah informasi akun yang akan Anda gunakan untuk mengakses situs untuk pertama kalinya.',
    'email_credentials' => 'Kirim kredensial melalui email',
    'email_credentials_text' => 'Kirim kredensial saya ke alamat email di atas',
    'next_save_user' => 'Selanjutnya: Simpan Pengguna',
    'all_assigned_list_generation' => 'Dihasilkan pada:',
    'email_user_creds_on_create' => 'Kirim kredensial pengguna ini melalui email?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/id-ID/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Pengguna ini dapat masuk',
    'activated_disabled_help_text' => 'Anda tidak dapat menyunting status aktivasi akun anda sendiri.',
    'assets_user'       => 'Aset pada :name',
    'bulk_update_warn'	=> 'Anda akan mengedit properti dari: user_count pengguna. Harap perhatikan bahwa Anda tidak dapat mengubah atribut pengguna Anda sendiri menggunakan formulir ini, dan harus melakukan pengeditan kepada pengguna Anda sendiri satu per satu.',
    'bulk_update_help'	=> 'Formulir ini memungkinkan Anda untuk memperbarui beberapa pengguna sekaligus. Isi saja bidang yang perlu Anda ubah. Setiap bidang yang dikosongkan akan tetap tidak berubah.',
    'current_assets'    => 'Aset ini untuk pengguna ini',
    'clone'             => 'Klon pengguna',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'Sunting Pengguna',
    'filetype_info'     => 'Jenis berkas diizinkan adalah png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, dan rar.',
    'history_user'      => 'Riwayat untuk :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klik di sini untuk mengembalikannya.',
    'last_login'        => 'Terakhir masuk',
    'ldap_config_text'  => 'Konfigurasi LDAP terdapat di Admin > Pengaturan. Jika lokasi di pilih, maka akan di impor untuk semua pengguna.',
    'print_assigned'    => 'Cetak Semua Ditugaskan',
    'email_assigned'    => 'Daftar Email Semua yang Ditetapkan',
    'user_notified'     => 'Pengguna telah dikirimi email berisi daftar item yang saat ini ditetapkan kepada mereka.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Sertakan pengguna ini saat penugasan otomatis lisensi yang memenuhi syarat',
    'auto_assign_help'  => 'Lewati pengguna ini dalam penetapan otomatis lisensi',
    'software_user'     => 'Perangkat lunak pada :name',
    'send_email_help'   => 'Anda harus memberikan alamat email pengguna ini untuk mengirimkan kredensial kepada mereka. Pengiriman email kredensial hanya dapat dilakukan pada pembuatan user. Kata sandi disimpan dalam hash satu arah dan tidak dapat diambil setelah disimpan.',
    'view_user'         => 'Lihat pengguna: name',
    'usercsv'           => 'Berkas CSV',
    'two_factor_admin_optin_help' => 'Pengaturan admin Anda saat ini memungkinkan penegakan dua faktor otentikasi selektif.',
    'two_factor_enrolled' => 'Perangkat 2FA Terdaftar',
    'two_factor_active'   => '2FA Aktif',
    'user_deactivated'  => 'Pengguna tidak dapat masuk',
    'user_activated'  => 'Pengguna dapat masuk',
    'activation_status_warning' => 'Jangan ubah status aktivasi',
    'group_memberships_helpblock' => 'Hanya superadmin yang dapat mengedit keanggotaan grup.',
    'superadmin_permission_warning' => 'Hanya superadmin yang dapat memberikan akses superadmin kepada pengguna.',
    'admin_permission_warning' => 'Hanya pengguna dengan hak admin atau lebih tinggi yang dapat memberikan akses admin kepada pengguna.',
    'remove_group_memberships' => 'Hapus Keanggotaan Grup',
    'warning_deletion_information' => 'Anda akan mengembalikan SEMUA item dari :count pengguna (-pengguna) yang terdaftar di bawah ini. Nama superadmin disorot dengan warna merah.',
    'update_user_assets_status' => 'Perbarui semua aset untuk pengguna ini ke status ini',
    'checkin_user_properties' => 'Kembalikan semua properti yang terkait dengan pengguna ini',
    'remote_label'   => 'Ini adalah pengguna jarak jauh',
    'remote'   => 'Jarak Jauh',
    'remote_help' => 'Ini dapat berguna jika Anda perlu memfilter berdasarkan pengguna jarak jauh yang tidak pernah atau jarang datang ke lokasi fisik Anda.',
    'not_remote_label' => 'Ini bukan pengguna jarak jauh',
    'vip_label' => 'Pengguna VIP',
    'vip_help' => 'Ini dapat bermanfaat untuk menandai orang-orang penting di organisasi Anda jika Anda ingin menangani mereka dengan cara khusus.',
    'create_user' => 'Buat pengguna',
    'create_user_page_explanation' => 'Ini adalah informasi akun yang akan Anda gunakan untuk mengakses situs untuk pertama kalinya.',
    'email_credentials' => 'Kirim kredensial melalui email',
    'email_credentials_text' => 'Kirim kredensial saya ke alamat email di atas',
    'next_save_user' => 'Selanjutnya: Simpan Pengguna',
    'all_assigned_list_generation' => 'Dihasilkan pada:',
    'email_user_creds_on_create' => 'Kirim kredensial pengguna ini melalui email?',
];
